[java-idp-integration-tests] branch main updated: Workaround Maven Surefire Plugin issue on Windows too

Tom Zeller tzeller at dragonacea.biz
Fri Dec 22 16:55:12 UTC 2023


This is an automated email from the git hooks/post-receive script.

tzeller pushed a commit to branch main
in repository java-idp-integration-tests.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-integration-tests.git;a=commit;h=dce850f1cb8cb31ece28e0b54c4f3c8987bbe49f

The following commit(s) were added to refs/heads/main by this push:
     new dce850f  Workaround Maven Surefire Plugin issue on Windows too
dce850f is described below

commit dce850f1cb8cb31ece28e0b54c4f3c8987bbe49f
Author: Tom Zeller <tzeller at dragonacea.biz>
AuthorDate: Fri Dec 22 10:53:27 2023 -0600

    Workaround Maven Surefire Plugin issue on Windows too
    
    Jetty 11 on Linux does not appear to be affected.
    
    Bumping the Maven Surefire Plugin to 3.2.3 does not help.
---
 .../net/shibboleth/idp/integration/tests/BaseIntegrationTest.java     | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
index 43ee6b6..52af08e 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
@@ -1093,8 +1093,8 @@ public abstract class BaseIntegrationTest {
         server.setStatusPageURL(getBaseURL() + StatusTest.statusPath);
         server.setShutdownPort(shutdownPort);
         server.initialize();
-        if (jettyVersion.startsWith("10")) {
-            // Workaround Maven Surefire Plugin freeze if Jetty 10 writes to stdout or stderr
+        if (jettyVersion.startsWith("10") || isWindows()) {
+            // Workaround Maven Surefire Plugin freeze if Jetty 10 or Windows writes to stdout or stderr
             server.getProcessBuilder().redirectOutput(Redirect.INHERIT);
             server.getProcessBuilder().redirectError(Redirect.INHERIT);
         }

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list